@@ -1,10 +1,10 @@
-class OceanKeeperContractsNotFound(Exception):
+class ContractsNotFound(Exception):
     """Raised when is not possible to find the keeper contracts abi."""
 
 
-class OceanDIDNotFound(Exception):
+class DIDNotFound(Exception):
     """Raised when a requested DID or a DID in the chain cannot be found."""
 
 
-class OceanInvalidTransaction(Exception):
+class InvalidTransaction(Exception):
     """Raised when an on-chain transaction fail."""
