@@ -2,6 +2,7 @@
 import uuid
 
 from contracts_lib_py.conditions.access import AccessCondition
+from contracts_lib_py.conditions.nft_access import NFTAccessCondition
 from tests.resources.helper_functions import get_consumer_account
 
 
@@ -12,6 +13,13 @@ def test_access_condition_contract():
         f'{access_condition} is not instance of AccessCondition'
 
 
+def test_nft_access_condition_contract():
+    nft_access_condition = NFTAccessCondition('NFTAccessCondition')
+    assert nft_access_condition
+    assert isinstance(nft_access_condition, NFTAccessCondition), \
+        f'{nft_access_condition} is not instance of NFTAccessCondition'
+
+
 def test_check_permissions_not_registered_did():
     access_condition = AccessCondition('AccessCondition')
     consumer_account = get_consumer_account()
